@@ -1,9 +1,18 @@
+import asyncio
 import importlib
 import os
 import pickle
+import queue
+import subprocess
 import threading
+import tkinter as tk
+import webbrowser
 from functools import partial
 from itertools import zip_longest
+from multiprocessing import Pipe, Process, Queue
+from queue import Queue
+from threading import Thread
+from tkinter import *
 
 import pygame
 import pygame_menu
@@ -14,7 +23,9 @@ from pygame_menu.locals import *
 from pygame_menu.widgets import *
 
 from primaryschool.dirs import *
+from primaryschool.dirs import user_screenshot_dir_path
 from primaryschool.locale import _
+from primaryschool.ready.psready import PSReady
 from primaryschool.resource import (
     default_font,
     default_font_path,
@@ -23,9 +34,6 @@ from primaryschool.resource import (
 )
 from primaryschool.settings import *
 from primaryschool.subjects import subjects
-import webbrowser
-from primaryschool.dirs import user_screenshot_dir_path
-import subprocess
 
 app_description_t = _("app_description_t")
 
@@ -155,11 +163,14 @@ class AboutMenu:
 
 
 class PlayMenu:
-    def __init__(self, ps):
+    def __init__(self, ps, return_main_menu=False):
         self.ps = ps
+        self.return_main_menu = return_main_menu
         self.title = _("Play Game")
+        self.tk_root = None
+        self.player_name_entry = None
         self.player_name = self.ps.player_name
-        self.player_name_text_input = None
+        self.player_name_button = None
         self._menu = self.ps.get_default_menu(self.title)
         self.subjects = self.ps.subjects
         self.subject_games = self.ps.subject_games
@@ -173,25 +184,16 @@ class PlayMenu:
         self.difficulty_dropselect = None
         self.continue_button = None
         self.selection_box_bgcolor = (255, 255, 255)
-        self.help_lael = None
-        self.help_lael_font = get_default_font(20)
+        self.help_label = None
+        self.help_label_font = get_default_font(20)
         self.esc_lael_font = get_default_font(16)
         self.esc_lael_font.set_bold(True)
-        self.help_lael_bg = (228, 0, 252, 30)
-        self.help_lael_border_color = (228, 0, 252, 200)
-
-    def set_player_name(self, name):
-        self.player_name = self.ps.player_name = name
-        if self.player_name_text_input:
-            self.player_name_text_input.set_value(self.player_name)
-
-    def get_player_name(self):
-        return self.player_name
+        self.help_label_bg = (228, 0, 252, 30)
+        self.help_label_border_color = (228, 0, 252, 200)
 
     def add_widgets(self):
-        self.player_name_text_input = self._menu.add.text_input(
-            title=_("Name :"),
-            default=self.get_player_name(),
+        self.player_name_button = self._menu.add.button(
+            _("Name :") + self.ps.get_player_name(),
             font_name=self.ps.font_path,
         )
 
@@ -242,21 +244,23 @@ class PlayMenu:
         )
         self.update_continue_button()
 
-        self._menu.add.button(
-            _("Return to main menu"),
-            pygame_menu.events.BACK,
-            font_name=self.ps.font_path,
-        )
+        if self.return_main_menu:
+            self._menu.add.button(
+                _("Return to main menu"),
+                pygame_menu.events.BACK,
+                font_name=self.ps.font_path,
+            )
 
-        self.help_lael = self._menu.add.label(
-            "", font_name=self.help_lael_font
+        self.help_label = self._menu.add.label(
+            "", font_name=self.help_label_font, max_char=-1
         )
-        self.update_help_lael()
+        self.update_help_label()
 
         self._menu.add.label(
             _("After starting the game, press ESC to return."),
             font_name=self.esc_lael_font,
             font_color=(255, 0, 0),
+            max_char=-1,
         )
 
     def update_selection_box_width(self):
@@ -300,10 +304,10 @@ class PlayMenu:
         )
         self.difficulty_dropselect.set_value(self.difficulty_index)
 
-    def update_help_lael(self):
-        self.help_lael.set_title(self.subject_game.help_t.strip())
-        self.help_lael.set_background_color(self.help_lael_bg)
-        self.help_lael.set_border(2, self.help_lael_border_color)
+    def update_help_label(self):
+        self.help_label.set_title(self.subject_game.help_t.strip())
+        self.help_label.set_background_color(self.help_label_bg)
+        self.help_label.set_border(2, self.help_label_border_color)
 
     def start_copied_game(self):
         self.subject_game.load(self.ps)
@@ -335,7 +339,7 @@ class PlayMenu:
         ]
         self.update_continue_button()
         self.set_difficulty_index()
-        self.update_help_lael()
+        self.update_help_label()
 
     def set_difficulty_index(self, index=0):
         self.difficulty_index = self.ps.difficulty_index = (
@@ -389,16 +393,33 @@ class MainMenu:
 
 
 class PrimarySchool:
-    def __init__(self):
-        pygame.init()
+    def __init__(
+        self,
+        surface=None,
+        mode_flags=pygame.RESIZABLE,
+        player_name=None,
+        caption=_("PrimarySchool"),
+        show_main_menu=False,
+        show_play_menu=True,
+    ):
+        if not pygame.get_init():
+            pygame.init()
+        self.show_main_menu = show_main_menu
+        self.show_play_menu = show_play_menu
+        self.caption = caption
+        pygame.display.set_caption(self.caption)
         self.running = True
-        self.surface = pygame.display.set_mode((0, 0), pygame.FULLSCREEN)
+        self.surface = (
+            surface
+            or getattr(self, "surface", None)
+            or pygame.display.set_mode((0, 0), mode_flags)
+        )
         self.w_width, self.w_height = self.surface.get_size()
         self.w_width_of_2 = self.w_width / 2
         self.w_height_of_2 = self.w_height / 2
         self.w_centrex_y = [self.w_width_of_2, self.w_height]
         self.FPS = 30
-        self.player_name = _("default_name")
+        self.player_name = player_name or _("default_name")
         self.clock = pygame.time.Clock()
         self.subjects = subjects
         self.subject_games = self.subjects[0].games
@@ -415,6 +436,12 @@ class PrimarySchool:
         self.save_menu = SaveMenu(self)
         self.main_menu = MainMenu(self)
 
+    def set_player_name(self, name):
+        self.player_name = name
+
+    def get_player_name(self):
+        return self.player_name
+
     def add_widgets(self):
         self.play_menu.add_widgets()
         self.about_menu.add_widgets()
@@ -454,12 +481,18 @@ class PrimarySchool:
             for event in events:
                 if event.type == pygame.QUIT:
                     exit()
-            if self.main_menu._menu.is_enabled():
-                self.main_menu._menu.mainloop(self.surface)
+            if self.show_main_menu:
+                if self.main_menu._menu.is_enabled():
+                    self.main_menu._menu.mainloop(self.surface)
+
+            if self.show_play_menu:
+                if self.play_menu._menu.is_enabled():
+                    self.play_menu._menu.mainloop(self.surface)
 
             pygame.display.flip()
 
 
 def go():
-    PrimarySchool().run()
-    pass
+    psready = PSReady()
+    psready.get_input()
+    PrimarySchool(player_name=psready.player_name).run()
