@@ -23,6 +23,7 @@ from primaryschool.resource import (
 from primaryschool.subjects import *
 from primaryschool.subjects._abc_ import GameBase
 from primaryschool.subjects._common_.keycode import PsKeyCode
+from primaryschool.subjects._common_.media import *
 
 
 class ShootingWave:
@@ -255,7 +256,7 @@ class TargetsManager:
         self,
         shtbase,
         frame_counter=None,
-        target_surface_lang_code=None,
+        lang_code=None,
         intercept_keycode=None,
     ):
 
@@ -265,34 +266,35 @@ class TargetsManager:
         self.moving_surfaces = []
         self.frame_counter = frame_counter or 30
         self.difficulty_index_p1 = self.shtbase.difficulty_index + 1
-        self.interval = 1.8 * self.shtbase.FPS
+        self.interval = 2.0 * self.shtbase.FPS
         self.intercept_interval = 0.3 * self.shtbase.FPS
-        self.moving_speed = (0,1)
+        self.moving_speed = (0, 0.6)
         self.intercepted_color = (175, 10, 175, 100)
         self.laser_color = (0, 0, 255, 90)
         self.laser_width = 2
         self.font_size = 50
-        self.target_surface_lang_code = (
-            target_surface_lang_code or sys_lang_code
-        )
-        self.font_path = get_font_path(self.target_surface_lang_code)
+        self.lang_code = lang_code or sys_lang_code
+        self.font_path = get_font_path(self.lang_code)
         self.font = pygame.font.Font(self.font_path, self.font_size)
         self.surfaces = []
         self.intercept_keycode = intercept_keycode
         self.target_count = 20
 
-    def set_moving_speed(self,speed=(0,1)):
+    def set_moving_speed(self, speed=(0, 1)):
+        """
+        The number of pixels moved per frame.
+        """
         self.moving_speed = speed
-    
+
     def get_moving_speed(self):
         return self.moving_speed
 
-    def set_interval(self,interval=1.8):
-        '''
+    def set_interval(self, interval=1.8):
+        """
         interval: The time interval at which the target appears, in seconds.
-        '''
+        """
         self.interval = interval * self.shtbase.FPS
-    
+
     def get_interval(self):
         return self.interval
 
@@ -322,8 +324,8 @@ class TargetsManager:
                 TargetSurface(self.shtbase, self, keys, lock, dest)
             )
 
-    def set_target_surface_lang_code(self, lang_code):
-        self.target_surface_lang_code = lang_code
+    def set_lang_code(self, lang_code):
+        self.lang_code = lang_code
 
     def set_target_count(self, target_count):
         self.target_count = target_count
@@ -641,6 +643,11 @@ class ScoreSurface(InfoSurface):
         self._pass = False
         self.score_font_size = 55
         self.score_font = get_default_font(self.score_font_size)
+        self.screenshot_saved_font_size = 45
+        self.screenshot_saved_font_color = (0, 200, 10)
+        self.screenshot_saved_font = get_default_font(
+            self.screenshot_saved_font_size
+        )
 
         self.datetime_diff_font_size = 50
         self.datetime_diff_font = get_default_font(
@@ -652,6 +659,50 @@ class ScoreSurface(InfoSurface):
         self.datetime_diff_surface = None
         self.greeting_surface = None
         self.end_time = self.ps.end_time = None
+        self.screenshot_path = get_default_screenshot_path(
+            self.shtbase.module_str, self.shtbase.ps.player_name
+        )
+        self.screenshot_saved = False
+        self.bg = None
+        self.pass_bg_path = default_score_surface_pass_bg_path
+        self.not_pass_bg_path = default_score_surface_not_pass_bg_path
+
+    def scale_bg(self):
+        self.bg = pygame.transform.scale(
+            self.bg, (self.ps.w_width, self.ps.w_height)
+        )
+
+    def get_bg(self):
+        if not self.bg:
+            self.set_bg()
+        return self.bg
+
+    def set_bg(self):
+        _bg_path = self.pass_bg_path if self._pass else self.not_pass_bg_path
+        self.bg = pygame.image.load(_bg_path)
+        self.scale_bg()
+
+    def set_bg_path(self, pass_bg_path=None, not_pass_bg_path=None):
+        if pass_bg_path:
+            self.pass_bg_path = pass_bg_path
+        if not_pass_bg_path:
+            self.not_pass_bg_path = not_pass_bg_path
+        if not pass_bg_path and not not_pass_bg_path:
+            self.pass_bg_path = default_score_surface_pass_bg_path
+            self.not_pass_bg_path = default_score_surface_not_pass_bg_path
+
+    def get_screenshot_path(self):
+        return self.screenshot_path
+
+    def set_screenshot_path(self, path):
+        self.screenshot_path = path
+
+    def take_screenshot(self):
+        if not self.screenshot_path:
+            print(_("Screenshot path is not set."))
+            return
+        pygame.image.save(self.shtbase.surface, self.get_screenshot_path())
+        print(_("Screenshot saved."))
 
     def get_score_font_color(self):
         return (20, 255, 0) if self._pass else (255, 20, 0)
@@ -689,6 +740,9 @@ class ScoreSurface(InfoSurface):
     def get_score_str(self):
         return _("Score: ") + str(self.score)
 
+    def get_screenshot_saved_str(self):
+        return _("Screenshot saved. Press Esc to RETURN")
+
     def get_greeting_dest(self):
         _w, _h = self.greeting_surface.get_size()
         _, _s_h = self.score_surface.get_size()
@@ -705,29 +759,59 @@ class ScoreSurface(InfoSurface):
         _w, _h = self.datetime_diff_surface.get_size()
         return [self.ps.w_width_of_2 - _w / 2, self.ps.w_height_of_2 + _h]
 
+    def get_screenshot_saved_surface_dest(self):
+        _w, _h = self.screenshot_saved_surface.get_size()
+        return [self.ps.w_width_of_2 - _w / 2, self.ps.w_height - _h]
+
+    def set_surfaces(self):
+        if (
+            not self.greeting_surface
+            or not self.score_surface
+            or not self.datetime_diff_surface
+        ):
+
+            self.score = self.get_score()
+            self.get_score_pass()
+
+            self.greeting_surface = self.score_font.render(
+                self.get_greeting(), False, self.get_score_font_color()
+            )
+
+            self.score_surface = self.score_font.render(
+                self.get_score_str(), False, self.get_score_font_color()
+            )
+
+            self.datetime_diff_surface = self.datetime_diff_font.render(
+                self.get_datetime_diff_str(),
+                False,
+                self.get_score_font_color(),
+            )
+            self.screenshot_saved_surface = self.screenshot_saved_font.render(
+                self.get_screenshot_saved_str(),
+                False,
+                self.screenshot_saved_font_color,
+            )
+
+    def blit_bg(self):
+        self.surface.blit(self.get_bg(), (0, 0))
+
     def blit(self):
-        self.score = self.get_score()
-        self.get_score_pass()
-
-        self.greeting_surface = self.score_font.render(
-            self.get_greeting(), False, self.get_score_font_color()
-        )
-
-        self.score_surface = self.score_font.render(
-            self.get_score_str(), False, self.get_score_font_color()
-        )
-
-        self.datetime_diff_surface = self.datetime_diff_font.render(
-            self.get_datetime_diff_str(), False, self.get_score_font_color()
-        )
 
+        self.set_surfaces()
+        self.blit_bg()
         self.surface.blit(self.greeting_surface, self.get_greeting_dest())
-
         self.surface.blit(self.score_surface, self.get_score_surface_dest())
-
         self.surface.blit(
             self.datetime_diff_surface, self.get_datetime_diff_surface_dest()
         )
+        if not self.screenshot_saved:
+            self.take_screenshot()
+            self.screenshot_saved = True
+        else:
+            self.surface.blit(
+                self.screenshot_saved_surface,
+                self.get_screenshot_saved_surface_dest(),
+            )
 
 
 class ShootingBase(GameBase, PsKeyCode):
